#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-hamlet
version:              0.5.0.3
visibility:           public
id:                   xml-hamlet-0.5.0.3-7b97d4M1MNUKBjPIQDoPKk
key:                  xml-hamlet-0.5.0.3-7b97d4M1MNUKBjPIQDoPKk
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  da0048abdc87acbd66ea6ef661343420
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xml-hamlet-0.5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.3-7b97d4M1MNUKBjPIQDoPKk
depends:
    base-4.18.2.1 containers-0.6.7 parsec-3.1.16.1
    shakespeare-2.2.0-AgK3wUD6y9e2SV2q027Hl4 template-haskell-2.20.0.0
    text-2.0.2 xml-conduit-1.9.1.4-BJAPIc3ZpEX9Hl5GLrN5ZY

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

